---
name: Feature request
about: Suggest something new
labels: enhancement
---

**What problem would this solve?**

**Describe the solution you'd like**

**Is this related to something in the existing roadmap?**
